@@ -1,7 +1,4 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha/configuration'
-require 'mocha/deprecation'
-require 'deprecation_disabler'
 
 class MockTest < Mocha::TestCase
   include AcceptanceTest
@@ -68,7 +65,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_mock_incorporating_two_expectations_which_are_satisifed
     test_result = run_as_test do
-      foo = mock(:bar => 'bar', :baz => 'baz')
+      foo = mock(bar: 'bar', baz: 'baz')
       foo.bar
       foo.baz
     end
@@ -77,7 +74,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_mock_incorporating_two_expectations_the_first_of_which_is_not_satisifed
     test_result = run_as_test do
-      foo = mock(:bar => 'bar', :baz => 'baz')
+      foo = mock(bar: 'bar', baz: 'baz')
       foo.baz
     end
     assert_failed(test_result)
@@ -85,7 +82,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_mock_incorporating_two_expectations_the_second_of_which_is_not_satisifed
     test_result = run_as_test do
-      foo = mock(:bar => 'bar', :baz => 'baz')
+      foo = mock(bar: 'bar', baz: 'baz')
       foo.bar
     end
     assert_failed(test_result)
@@ -93,7 +90,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_string_named_mock_incorporating_two_expectations_which_are_satisifed
     test_result = run_as_test do
-      foo = mock('foo', :bar => 'bar', :baz => 'baz')
+      foo = mock('foo', bar: 'bar', baz: 'baz')
       foo.bar
       foo.baz
     end
@@ -102,7 +99,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_symbol_named_mock_incorporating_two_expectations_which_are_satisifed
     test_result = run_as_test do
-      foo = mock(:foo, :bar => 'bar', :baz => 'baz')
+      foo = mock(:foo, bar: 'bar', baz: 'baz')
       foo.bar
       foo.baz
     end
@@ -111,7 +108,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_string_named_mock_incorporating_two_expectations_the_first_of_which_is_not_satisifed
     test_result = run_as_test do
-      foo = mock('foo', :bar => 'bar', :baz => 'baz')
+      foo = mock('foo', bar: 'bar', baz: 'baz')
       foo.baz
     end
     assert_failed(test_result)
@@ -119,7 +116,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_symbol_named_mock_incorporating_two_expectations_the_first_of_which_is_not_satisifed
     test_result = run_as_test do
-      foo = mock(:foo, :bar => 'bar', :baz => 'baz')
+      foo = mock(:foo, bar: 'bar', baz: 'baz')
       foo.baz
     end
     assert_failed(test_result)
@@ -127,7 +124,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_string_named_mock_incorporating_two_expectations_the_second_of_which_is_not_satisifed
     test_result = run_as_test do
-      foo = mock('foo', :bar => 'bar', :baz => 'baz')
+      foo = mock('foo', bar: 'bar', baz: 'baz')
       foo.bar
     end
     assert_failed(test_result)
@@ -135,7 +132,7 @@ class MockTest < Mocha::TestCase
 
   def test_should_build_symbol_named_mock_incorporating_two_expectations_the_second_of_which_is_not_satisifed
     test_result = run_as_test do
-      foo = mock(:foo, :bar => 'bar', :baz => 'baz')
+      foo = mock(:foo, bar: 'bar', baz: 'baz')
       foo.bar
     end
     assert_failed(test_result)
@@ -151,8 +148,7 @@ class MockTest < Mocha::TestCase
     end
   end
 
-  # rubocop:disable Metrics/AbcSize
-  def test_should_display_deprecation_warning_if_mock_receives_invocations_in_another_test
+  def test_should_raise_stubbing_error_if_mock_receives_invocations_in_another_test
     use_mock_test_result = run_as_test do
       Foo.logger = mock('Logger')
       Foo.logger.expects(:log).with('Foo was here')
@@ -161,17 +157,12 @@ class MockTest < Mocha::TestCase
     assert_passed(use_mock_test_result)
 
     reuse_mock_test_result = run_as_test do
-      DeprecationDisabler.disable_deprecations do
-        Foo.logger.expects(:log).with('Foo was here')
-        Foo.new.use_the_mock
-      end
+      Foo.logger.expects(:log).with('Foo was here')
+      e = assert_raises(Mocha::StubbingError) { Foo.new.use_the_mock }
+      assert e.message.include?('#<Mock:Logger> was instantiated in one test but it is receiving invocations within another test.')
+      assert e.message.include?('This can lead to unintended interactions between tests and hence unexpected test failures.')
+      assert e.message.include?('Ensure that every test correctly cleans up any state that it introduces.')
     end
     assert_passed(reuse_mock_test_result)
-    assert message = Deprecation.messages.last
-    assert message.include?('#<Mock:Logger> was instantiated in one test but it is receiving invocations within another test.')
-    assert message.include?('This can lead to unintended interactions between tests and hence unexpected test failures.')
-    assert message.include?('Ensure that every test correctly cleans up any state that it introduces.')
-    assert message.include?('A Mocha::StubbingError will be raised in this scenario in the future.')
   end
-  # rubocop:enable Metrics/AbcSize
 end
